==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/DomainChartSeriesPointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { DomainChartSeriesPointerEventArgsDescription } from "./DomainChartSeriesPointerEventArgsDescription";
/**
 * @hidden
 */
var DomainChartSeriesPointerEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DomainChartSeriesPointerEventArgsDescriptionMetadata, _super);
    function DomainChartSeriesPointerEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DomainChartSeriesPointerEventArgsDescriptionMetadata.b = function (a) {
        if (DomainChartSeriesPointerEventArgsDescriptionMetadata.a == null) {
            DomainChartSeriesPointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DomainChartSeriesPointerEventArgsDescriptionMetadata.c(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
        }
        if (a.k(DomainChartSeriesPointerEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    DomainChartSeriesPointerEventArgsDescriptionMetadata.c = function (a) {
        a.item("Series", "ExportedType:Series");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
    };
    DomainChartSeriesPointerEventArgsDescriptionMetadata.d = function (a) {
        DomainChartSeriesPointerEventArgsDescriptionMetadata.b(a);
        a.ac("DomainChartSeriesPointerEventArgs", function () { return new DomainChartSeriesPointerEventArgsDescription(); });
        a.ab("DomainChartSeriesPointerEventArgs", DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
    };
    DomainChartSeriesPointerEventArgsDescriptionMetadata.$t = markType(DomainChartSeriesPointerEventArgsDescriptionMetadata, 'DomainChartSeriesPointerEventArgsDescriptionMetadata');
    DomainChartSeriesPointerEventArgsDescriptionMetadata.a = null;
    return DomainChartSeriesPointerEventArgsDescriptionMetadata;
}(Base));
export { DomainChartSeriesPointerEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.2.tgz: package/esm5/lib/DomainChartSeriesPointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { DomainChartSeriesPointerEventArgsDescription } from "./DomainChartSeriesPointerEventArgsDescription";
/**
 * @hidden
 */
var DomainChartSeriesPointerEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DomainChartSeriesPointerEventArgsDescriptionMetadata, _super);
    function DomainChartSeriesPointerEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DomainChartSeriesPointerEventArgsDescriptionMetadata.b = function (a) {
        if (DomainChartSeriesPointerEventArgsDescriptionMetadata.a == null) {
            DomainChartSeriesPointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DomainChartSeriesPointerEventArgsDescriptionMetadata.c(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
        }
        if (a.k(DomainChartSeriesPointerEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    DomainChartSeriesPointerEventArgsDescriptionMetadata.c = function (a) {
        a.item("Series", "ExportedType:Series");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("PlotAreaPosition", "Point");
    };
    DomainChartSeriesPointerEventArgsDescriptionMetadata.d = function (a) {
        DomainChartSeriesPointerEventArgsDescriptionMetadata.b(a);
        a.ae("DomainChartSeriesPointerEventArgs", function () { return new DomainChartSeriesPointerEventArgsDescription(); });
        a.ad("DomainChartSeriesPointerEventArgs", DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
    };
    DomainChartSeriesPointerEventArgsDescriptionMetadata.$t = markType(DomainChartSeriesPointerEventArgsDescriptionMetadata, 'DomainChartSeriesPointerEventArgsDescriptionMetadata');
    DomainChartSeriesPointerEventArgsDescriptionMetadata.a = null;
    return DomainChartSeriesPointerEventArgsDescriptionMetadata;
}(Base));
export { DomainChartSeriesPointerEventArgsDescriptionMetadata };
